# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import experiment_details_pb2 as grid_dot_v1_dot_experiment__details__pb2


class ExperimentDetailsServiceStub(object):
    """This is experiment details service which should be implemented in the gridlet
  with control plane optionally proxying it/redirecting to it
  """
    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.GetLogs = channel.unary_unary(
            '/grid.v1.ExperimentDetailsService/GetLogs',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsResponse.FromString,
        )
        self.WatchLogs = channel.unary_stream(
            '/grid.v1.ExperimentDetailsService/WatchLogs',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsResponse.FromString,
        )
        self.ListArtifacts = channel.unary_unary(
            '/grid.v1.ExperimentDetailsService/ListArtifacts',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsResponse.FromString,
        )
        self.WatchArtifacts = channel.unary_stream(
            '/grid.v1.ExperimentDetailsService/WatchArtifacts',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsResponse.FromString,
        )
        self.GetExperimentMetrics = channel.unary_unary(
            '/grid.v1.ExperimentDetailsService/GetExperimentMetrics',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsResponse.FromString,
        )
        self.ListAvailableMetrics = channel.unary_unary(
            '/grid.v1.ExperimentDetailsService/ListAvailableMetrics',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsResponse.FromString,
        )
        self.WatchExperimentMetrics = channel.unary_stream(
            '/grid.v1.ExperimentDetailsService/WatchExperimentMetrics',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsResponse.FromString,
        )
        self.GetExperimentCost = channel.unary_unary(
            '/grid.v1.ExperimentDetailsService/GetExperimentCost',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostResponse.FromString,
        )
        self.GetSessionCost = channel.unary_unary(
            '/grid.v1.ExperimentDetailsService/GetSessionCost',
            request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostResponse.FromString,
        )


class ExperimentDetailsServiceServicer(object):
    """This is experiment details service which should be implemented in the gridlet
  with control plane optionally proxying it/redirecting to it
  """
    def GetLogs(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchLogs(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListArtifacts(self, request, context):
        """artifacts
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchArtifacts(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExperimentMetrics(self, request, context):
        """metrics
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAvailableMetrics(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchExperimentMetrics(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExperimentCost(self, request, context):
        """cost
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSessionCost(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExperimentDetailsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'GetLogs':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetLogs,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsResponse.SerializeToString,
        ),
        'WatchLogs':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchLogs,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsResponse.SerializeToString,
        ),
        'ListArtifacts':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListArtifacts,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsResponse.SerializeToString,
        ),
        'WatchArtifacts':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchArtifacts,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsResponse.SerializeToString,
        ),
        'GetExperimentMetrics':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetExperimentMetrics,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsResponse.SerializeToString,
        ),
        'ListAvailableMetrics':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListAvailableMetrics,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsResponse.SerializeToString,
        ),
        'WatchExperimentMetrics':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchExperimentMetrics,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsResponse.
            SerializeToString,
        ),
        'GetExperimentCost':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetExperimentCost,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostResponse.SerializeToString,
        ),
        'GetSessionCost':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetSessionCost,
            request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.ExperimentDetailsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/run_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import run_pb2 as grid_dot_v1_dot_run__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/run_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x19grid/v1/run_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x11grid/v1/run.proto\"2\n\x10\x43reateRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11\x43reateRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"\x1f\n\rGetRunRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"0\n\x0eGetRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"y\n\x0fListRunsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\"\x84\x01\n\x10ListRunsResponse\x12\x1e\n\x03run\x18\x01 \x03(\x0b\x32\x0c.grid.v1.RunR\x03run\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"2\n\x10UpdateRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11UpdateRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"8\n\x16UpdateRunStatusRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"9\n\x17UpdateRunStatusResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"2\n\x10\x44\x65leteRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11\x44\x65leteRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"S\n\x10WatchRunsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\"\x8b\x01\n\x11WatchRunsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x17.grid.v1.WatchEventTypeR\x04type\x12\x1e\n\x03run\x18\x03 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run2\xfa\x03\n\nRunService\x12\x44\n\tCreateRun\x12\x19.grid.v1.CreateRunRequest\x1a\x1a.grid.v1.CreateRunResponse\"\x00\x12;\n\x06GetRun\x12\x16.grid.v1.GetRunRequest\x1a\x17.grid.v1.GetRunResponse\"\x00\x12\x41\n\x08ListRuns\x12\x18.grid.v1.ListRunsRequest\x1a\x19.grid.v1.ListRunsResponse\"\x00\x12\x44\n\tUpdateRun\x12\x19.grid.v1.UpdateRunRequest\x1a\x1a.grid.v1.UpdateRunResponse\"\x00\x12T\n\x0fUpdateRunStatus\x12\x1f.grid.v1.UpdateRunStatusRequest\x1a .grid.v1.UpdateRunStatusResponse\x12\x44\n\tDeleteRun\x12\x19.grid.v1.DeleteRunRequest\x1a\x1a.grid.v1.DeleteRunResponse\"\x00\x12\x44\n\tWatchRuns\x12\x19.grid.v1.WatchRunsRequest\x1a\x1a.grid.v1.WatchRunsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_run__pb2.DESCRIPTOR,
    ]
)

_CREATERUNREQUEST = _descriptor.Descriptor(
    name='CreateRunRequest',
    full_name='grid.v1.CreateRunRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.CreateRunRequest.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=111,
    serialized_end=161,
)

_CREATERUNRESPONSE = _descriptor.Descriptor(
    name='CreateRunResponse',
    full_name='grid.v1.CreateRunResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.CreateRunResponse.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=163,
    serialized_end=214,
)

_GETRUNREQUEST = _descriptor.Descriptor(
    name='GetRunRequest',
    full_name='grid.v1.GetRunRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='id',
            full_name='grid.v1.GetRunRequest.id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='id',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=216,
    serialized_end=247,
)

_GETRUNRESPONSE = _descriptor.Descriptor(
    name='GetRunResponse',
    full_name='grid.v1.GetRunResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.GetRunResponse.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=249,
    serialized_end=297,
)

_LISTRUNSREQUEST = _descriptor.Descriptor(
    name='ListRunsRequest',
    full_name='grid.v1.ListRunsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListRunsRequest.continue_token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListRunsRequest.resource_version',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.ListRunsRequest.limit',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=299,
    serialized_end=420,
)

_LISTRUNSRESPONSE = _descriptor.Descriptor(
    name='ListRunsResponse',
    full_name='grid.v1.ListRunsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.ListRunsResponse.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='continue_token',
            full_name='grid.v1.ListRunsResponse.continue_token',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='continueToken',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.ListRunsResponse.resource_version',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=423,
    serialized_end=555,
)

_UPDATERUNREQUEST = _descriptor.Descriptor(
    name='UpdateRunRequest',
    full_name='grid.v1.UpdateRunRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.UpdateRunRequest.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=557,
    serialized_end=607,
)

_UPDATERUNRESPONSE = _descriptor.Descriptor(
    name='UpdateRunResponse',
    full_name='grid.v1.UpdateRunResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.UpdateRunResponse.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=609,
    serialized_end=660,
)

_UPDATERUNSTATUSREQUEST = _descriptor.Descriptor(
    name='UpdateRunStatusRequest',
    full_name='grid.v1.UpdateRunStatusRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.UpdateRunStatusRequest.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=662,
    serialized_end=718,
)

_UPDATERUNSTATUSRESPONSE = _descriptor.Descriptor(
    name='UpdateRunStatusResponse',
    full_name='grid.v1.UpdateRunStatusResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.UpdateRunStatusResponse.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=720,
    serialized_end=777,
)

_DELETERUNREQUEST = _descriptor.Descriptor(
    name='DeleteRunRequest',
    full_name='grid.v1.DeleteRunRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.DeleteRunRequest.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=779,
    serialized_end=829,
)

_DELETERUNRESPONSE = _descriptor.Descriptor(
    name='DeleteRunResponse',
    full_name='grid.v1.DeleteRunResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.DeleteRunResponse.run',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=831,
    serialized_end=882,
)

_WATCHRUNSREQUEST = _descriptor.Descriptor(
    name='WatchRunsRequest',
    full_name='grid.v1.WatchRunsRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchRunsRequest.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='limit',
            full_name='grid.v1.WatchRunsRequest.limit',
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='limit',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=884,
    serialized_end=967,
)

_WATCHRUNSRESPONSE = _descriptor.Descriptor(
    name='WatchRunsResponse',
    full_name='grid.v1.WatchRunsResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='resource_version',
            full_name='grid.v1.WatchRunsResponse.resource_version',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceVersion',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.WatchRunsResponse.type',
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='run',
            full_name='grid.v1.WatchRunsResponse.run',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='run',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=970,
    serialized_end=1109,
)

_CREATERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_CREATERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_GETRUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_LISTRUNSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNSTATUSREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNSTATUSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_DELETERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_DELETERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_WATCHRUNSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_metadata__pb2._WATCHEVENTTYPE
_WATCHRUNSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
DESCRIPTOR.message_types_by_name['CreateRunRequest'] = _CREATERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateRunResponse'] = _CREATERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetRunRequest'] = _GETRUNREQUEST
DESCRIPTOR.message_types_by_name['GetRunResponse'] = _GETRUNRESPONSE
DESCRIPTOR.message_types_by_name['ListRunsRequest'] = _LISTRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListRunsResponse'] = _LISTRUNSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunRequest'] = _UPDATERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunResponse'] = _UPDATERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunStatusRequest'] = _UPDATERUNSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunStatusResponse'] = _UPDATERUNSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRunRequest'] = _DELETERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteRunResponse'] = _DELETERUNRESPONSE
DESCRIPTOR.message_types_by_name['WatchRunsRequest'] = _WATCHRUNSREQUEST
DESCRIPTOR.message_types_by_name['WatchRunsResponse'] = _WATCHRUNSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateRunRequest = _reflection.GeneratedProtocolMessageType(
    'CreateRunRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATERUNREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateRunRequest)
    }
)
_sym_db.RegisterMessage(CreateRunRequest)

CreateRunResponse = _reflection.GeneratedProtocolMessageType(
    'CreateRunResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _CREATERUNRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.CreateRunResponse)
    }
)
_sym_db.RegisterMessage(CreateRunResponse)

GetRunRequest = _reflection.GeneratedProtocolMessageType(
    'GetRunRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETRUNREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetRunRequest)
    }
)
_sym_db.RegisterMessage(GetRunRequest)

GetRunResponse = _reflection.GeneratedProtocolMessageType(
    'GetRunResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _GETRUNRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.GetRunResponse)
    }
)
_sym_db.RegisterMessage(GetRunResponse)

ListRunsRequest = _reflection.GeneratedProtocolMessageType(
    'ListRunsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTRUNSREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListRunsRequest)
    }
)
_sym_db.RegisterMessage(ListRunsRequest)

ListRunsResponse = _reflection.GeneratedProtocolMessageType(
    'ListRunsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LISTRUNSRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ListRunsResponse)
    }
)
_sym_db.RegisterMessage(ListRunsResponse)

UpdateRunRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateRunRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATERUNREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunRequest)
    }
)
_sym_db.RegisterMessage(UpdateRunRequest)

UpdateRunResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateRunResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATERUNRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunResponse)
    }
)
_sym_db.RegisterMessage(UpdateRunResponse)

UpdateRunStatusRequest = _reflection.GeneratedProtocolMessageType(
    'UpdateRunStatusRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATERUNSTATUSREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunStatusRequest)
    }
)
_sym_db.RegisterMessage(UpdateRunStatusRequest)

UpdateRunStatusResponse = _reflection.GeneratedProtocolMessageType(
    'UpdateRunStatusResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _UPDATERUNSTATUSRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunStatusResponse)
    }
)
_sym_db.RegisterMessage(UpdateRunStatusResponse)

DeleteRunRequest = _reflection.GeneratedProtocolMessageType(
    'DeleteRunRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETERUNREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteRunRequest)
    }
)
_sym_db.RegisterMessage(DeleteRunRequest)

DeleteRunResponse = _reflection.GeneratedProtocolMessageType(
    'DeleteRunResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DELETERUNRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DeleteRunResponse)
    }
)
_sym_db.RegisterMessage(DeleteRunResponse)

WatchRunsRequest = _reflection.GeneratedProtocolMessageType(
    'WatchRunsRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHRUNSREQUEST,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchRunsRequest)
    }
)
_sym_db.RegisterMessage(WatchRunsRequest)

WatchRunsResponse = _reflection.GeneratedProtocolMessageType(
    'WatchRunsResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _WATCHRUNSRESPONSE,
        '__module__': 'grid.v1.run_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.WatchRunsResponse)
    }
)
_sym_db.RegisterMessage(WatchRunsResponse)

DESCRIPTOR._options = None

_RUNSERVICE = _descriptor.ServiceDescriptor(
    name='RunService',
    full_name='grid.v1.RunService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=1112,
    serialized_end=1618,
    methods=[
        _descriptor.MethodDescriptor(
            name='CreateRun',
            full_name='grid.v1.RunService.CreateRun',
            index=0,
            containing_service=None,
            input_type=_CREATERUNREQUEST,
            output_type=_CREATERUNRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='GetRun',
            full_name='grid.v1.RunService.GetRun',
            index=1,
            containing_service=None,
            input_type=_GETRUNREQUEST,
            output_type=_GETRUNRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='ListRuns',
            full_name='grid.v1.RunService.ListRuns',
            index=2,
            containing_service=None,
            input_type=_LISTRUNSREQUEST,
            output_type=_LISTRUNSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateRun',
            full_name='grid.v1.RunService.UpdateRun',
            index=3,
            containing_service=None,
            input_type=_UPDATERUNREQUEST,
            output_type=_UPDATERUNRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='UpdateRunStatus',
            full_name='grid.v1.RunService.UpdateRunStatus',
            index=4,
            containing_service=None,
            input_type=_UPDATERUNSTATUSREQUEST,
            output_type=_UPDATERUNSTATUSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='DeleteRun',
            full_name='grid.v1.RunService.DeleteRun',
            index=5,
            containing_service=None,
            input_type=_DELETERUNREQUEST,
            output_type=_DELETERUNRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='WatchRuns',
            full_name='grid.v1.RunService.WatchRuns',
            index=6,
            containing_service=None,
            input_type=_WATCHRUNSREQUEST,
            output_type=_WATCHRUNSRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_RUNSERVICE)

DESCRIPTOR.services_by_name['RunService'] = _RUNSERVICE

# @@protoc_insertion_point(module_scope)



"""
Set of environments that change the global state of the CLI.

Variables
---------

    * `ENVIRONMENT`: Describes which environment the application is
    running in. This can be either `production` or `development`.
    This variable determines a number of behavior changes in the app,
    including logging, tracking, and error handling.

    * `GRID_URL`: Address used to register with GitHub as an Oauth
    provider. This must match what is registered in GitHub.

    * `DEBUG`: If gridrunner should print additional information for
    debugging purposes.

    * `SHOW_PROCESS_STATUS_DETAILS`: Global flag used to print Run submit details.

    * `SEGMENT_KEY`: Key to send data analytics to Segment.

    * `GRID_DISABLE_TRACKING`: If tracking should be disabled

    * `IGNORE_WARNINGS`: if we should ignore warning prompts throughout the CLI.

    * `GRID_SKIP_VERSION_CHECK`: skips version check between client and backend.

"""
import logging
import os

from grid.cli.utilities import get_graphql_url

ENVIRONMENT = os.getenv('ENVIRONMENT', 'development')

DEFAULT_GRID_URL = 'https://platform.grid.ai/graphql'
GRID_URL = get_graphql_url(os.getenv('GRID_URL', DEFAULT_GRID_URL))

USER_ID = os.getenv('GRID_USER_ID')
API_KEY = os.getenv('GRID_API_KEY')
SEGMENT_KEY = os.getenv('SEGMENT_KEY', "VqTtJqOy7yCzJFhoyfNAT5IJusE8zVQR")
GRID_DISABLE_TRACKING = os.getenv('GRID_DISABLE_TRACKING')

DEBUG = bool(os.getenv('DEBUG'))

logger = logging.getLogger(__name__)  # pragma: no cover

SHOW_PROCESS_STATUS_DETAILS = False

IGNORE_WARNINGS = None

SKIP_VERSION_CHECK = bool(os.getenv('GRID_SKIP_VERSION_CHECK'))

GRID_SSH_CONFIG = os.getenv("GRID_SSH_CONFIG", default=os.path.join(os.path.expanduser("~"), ".ssh", "config"))



from collections import defaultdict
from typing import Optional

import click
from rich.console import Console

from grid import get_instance_types
from grid.cli import rich_click
from grid.cli.observables import BaseObservable
from grid.sdk import list_clusters


@rich_click.command('instance-types')
@click.option(
    '--cluster',
    'cluster_id',
    type=str,
    required=False,
    help='Cluster ID whence the instance types needs to be fetched. (Bring Your Own Cloud Customers Only).'
)
def instance_types(cluster_id: Optional[str] = None):
    if cluster_id is None:
        clusters = list_clusters()
        if len(clusters) == 0:
            raise click.ClickException('No clusters found. Raise the issue with Grid support')

        cluster_id = clusters[0].id

        if len(clusters) > 1:
            cluster_ids = [c.id for c in clusters]
            click.echo(
                f'Found multiple clusters: {", ".join(cluster_ids)}'
                f'\n\nShowing the result for {cluster_id}. Use `--cluster` argument to specify cluster'
            )
    instances = get_instance_types(cluster_id=cluster_id)
    instance_dict = defaultdict(dict)
    table = BaseObservable.create_table(columns=['Name', 'On-demand Cost', 'Spot Cost', 'CPU', 'GPU', 'Memory'])

    for i in instances:
        if i.spot:
            instance_dict[i.name]['spot_cost'] = i.hourly_cost
        else:
            instance_dict[i.name]['on_demand_cost'] = i.hourly_cost
        # these fields shouldn't be different for spot/on-demand
        instance_dict[i.name]['cpu'] = i.cpu
        instance_dict[i.name]['gpu'] = i.gpu
        instance_dict[i.name]['memory'] = i.memory

    for name, det in instance_dict.items():
        on_demand_cost = str(det.get('on_demand_cost') or "Not Available")
        spot_cost = str(det.get('spot_cost') or "Not Available")
        table.add_row(name, on_demand_cost, spot_cost, det['cpu'], det['gpu'], det['memory'])
    console = Console()
    console.print(table)
